@@ -2,12 +2,17 @@ from __future__ import annotations
 from typing import Optional
 from pydantic import BaseModel
 
+class Me(BaseModel):
+    shop_id: int
+    user_id: int
+    
+
 class OtherUser(BaseModel):
     user_id: int
-    email: Optional[str]
+    primary_email: Optional[str]
     first_name: Optional[str]
     last_name: Optional[str]
-    picture: Optional[str]
+    image_url_75x75: Optional[str]
 
 
 class User(BaseModel):
