@@ -326,4 +326,9 @@ class ListingResource:
         return ProductProperty(**response)
     
     
+    async def aget_listing_by_id(self, listing_id: int, includes):
+        endpoint = f"listings/{listing_id}"
+        json = await self.session.async_request(endpoint, params={"includes":includes})
+        return Listing(**json)
+    
     
\ No newline at end of file
