@@ -1,9 +1,8 @@
 from dataclasses import dataclass
 #from etsy_apiv3.utils.APIV3 import EtsyAuth
-from etsy_apiv3.utils.Response import Response
-from etsy_apiv3.models.ReviewModel import Review
 from async_oauthlib import OAuth2Session as AsyncOAuth2Session
-from etsy_apiv3.utils.APIV3 import EtsySession
+from ..utils import Response, EtsySession
+from ..models.ReviewModel import Review
 
 @dataclass
 class ReviewResource:
