@@ -105,11 +105,12 @@ class EtsySession:
         if headers is None:
             headers = {"x-api-key": self.CLIENT_KEY}
 
-        async with self.__async_oauth2_session.request(url=url, method=method, headers=headers, *args, **kwargs) as res:
+        res = self.__async_oauth2_session.request(url=url, method=method, headers=headers, *args, **kwargs)
             
-            json = await res.json()
-            
-            if "error" in json.keys():
-                raise EtsyRequestException(res.status_code, json["error"])
-
-            return json
+        json = await res.json()
+        
+        if "error" in json.keys():
+            raise EtsyRequestException(res.status_code, json["error"])
+        res.close()
+        
+        return json
